Documentation
¶
Overview ¶
Package treatment provides primitives to interact with the openapi HTTP API.
Code generated by github.com/deepmap/oapi-codegen version v1.8.1 DO NOT EDIT.
Index ¶
- func NewFetchTreatmentRequest(server string, projectId int64, params *FetchTreatmentParams, ...) (*http.Request, error)
- func NewFetchTreatmentRequestWithBody(server string, projectId int64, params *FetchTreatmentParams, ...) (*http.Request, error)
- type Client
- type ClientInterface
- type ClientOption
- type ClientWithResponses
- func (c *ClientWithResponses) FetchTreatmentWithBodyWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, ...) (*FetchTreatmentResponse, error)
- func (c *ClientWithResponses) FetchTreatmentWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, ...) (*FetchTreatmentResponse, error)
- type ClientWithResponsesInterface
- type FetchTreatmentBadRequest
- type FetchTreatmentJSONRequestBody
- type FetchTreatmentParams
- type FetchTreatmentRequestBody
- type FetchTreatmentResponse
- type FetchTreatmentSuccess
- type HttpRequestDoer
- type InternalServerError
- type RequestEditorFn
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFetchTreatmentRequest ¶
func NewFetchTreatmentRequest(server string, projectId int64, params *FetchTreatmentParams, body FetchTreatmentJSONRequestBody) (*http.Request, error)
NewFetchTreatmentRequest calls the generic FetchTreatment builder with application/json body
Types ¶
type Client ¶
type Client struct {
// The endpoint of the server conforming to this interface, with scheme,
// https://api.deepmap.com for example. This can contain a path relative
// to the server, such as https://api.deepmap.com/dev-test, and all the
// paths in the swagger spec will be appended to the server.
Server string
// Doer for performing requests, typically a *http.Client with any
// customized settings, such as certificate chains.
Client HttpRequestDoer
// A list of callbacks for modifying requests which are generated before sending over
// the network.
RequestEditors []RequestEditorFn
}
Client which conforms to the OpenAPI3 specification for this service.
func NewClient ¶
func NewClient(server string, opts ...ClientOption) (*Client, error)
Creates a new Client, with reasonable defaults
func (*Client) FetchTreatment ¶
func (c *Client) FetchTreatment(ctx context.Context, projectId int64, params *FetchTreatmentParams, body FetchTreatmentJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)
func (*Client) FetchTreatmentWithBody ¶
type ClientInterface ¶
type ClientInterface interface {
// FetchTreatment request with any body
FetchTreatmentWithBody(ctx context.Context, projectId int64, params *FetchTreatmentParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)
FetchTreatment(ctx context.Context, projectId int64, params *FetchTreatmentParams, body FetchTreatmentJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)
}
The interface specification for the client above.
type ClientOption ¶
ClientOption allows setting custom parameters during construction
func WithHTTPClient ¶
func WithHTTPClient(doer HttpRequestDoer) ClientOption
WithHTTPClient allows overriding the default Doer, which is automatically created using http.Client. This is useful for tests.
func WithRequestEditorFn ¶
func WithRequestEditorFn(fn RequestEditorFn) ClientOption
WithRequestEditorFn allows setting up a callback function, which will be called right before sending the request. This can be used to mutate the request.
type ClientWithResponses ¶
type ClientWithResponses struct {
ClientInterface
}
ClientWithResponses builds on ClientInterface to offer response payloads
func NewClientWithResponses ¶
func NewClientWithResponses(server string, opts ...ClientOption) (*ClientWithResponses, error)
NewClientWithResponses creates a new ClientWithResponses, which wraps Client with return type handling
func (*ClientWithResponses) FetchTreatmentWithBodyWithResponse ¶
func (c *ClientWithResponses) FetchTreatmentWithBodyWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*FetchTreatmentResponse, error)
FetchTreatmentWithBodyWithResponse request with arbitrary body returning *FetchTreatmentResponse
func (*ClientWithResponses) FetchTreatmentWithResponse ¶
func (c *ClientWithResponses) FetchTreatmentWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, body FetchTreatmentJSONRequestBody, reqEditors ...RequestEditorFn) (*FetchTreatmentResponse, error)
type ClientWithResponsesInterface ¶
type ClientWithResponsesInterface interface {
// FetchTreatment request with any body
FetchTreatmentWithBodyWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*FetchTreatmentResponse, error)
FetchTreatmentWithResponse(ctx context.Context, projectId int64, params *FetchTreatmentParams, body FetchTreatmentJSONRequestBody, reqEditors ...RequestEditorFn) (*FetchTreatmentResponse, error)
}
ClientWithResponsesInterface is the interface specification for the client with responses above.
type FetchTreatmentBadRequest ¶
type FetchTreatmentBadRequest externalRef0.Error
FetchTreatmentBadRequest defines model for FetchTreatmentBadRequest.
type FetchTreatmentJSONRequestBody ¶
type FetchTreatmentJSONRequestBody FetchTreatmentRequestBody
FetchTreatmentJSONRequestBody defines body for FetchTreatment for application/json ContentType.
type FetchTreatmentParams ¶
type FetchTreatmentParams struct {
PassKey string `json:"pass-key"`
}
FetchTreatmentParams defines parameters for FetchTreatment.
type FetchTreatmentRequestBody ¶
type FetchTreatmentRequestBody struct {
AdditionalProperties map[string]interface{} `json:"-"`
}
FetchTreatmentRequestBody defines model for FetchTreatmentRequestBody.
func (FetchTreatmentRequestBody) Get ¶
func (a FetchTreatmentRequestBody) Get(fieldName string) (value interface{}, found bool)
Getter for additional properties for FetchTreatmentRequestBody. Returns the specified element and whether it was found
func (FetchTreatmentRequestBody) MarshalJSON ¶
func (a FetchTreatmentRequestBody) MarshalJSON() ([]byte, error)
Override default JSON handling for FetchTreatmentRequestBody to handle AdditionalProperties
func (*FetchTreatmentRequestBody) Set ¶
func (a *FetchTreatmentRequestBody) Set(fieldName string, value interface{})
Setter for additional properties for FetchTreatmentRequestBody
func (*FetchTreatmentRequestBody) UnmarshalJSON ¶
func (a *FetchTreatmentRequestBody) UnmarshalJSON(b []byte) error
Override default JSON handling for FetchTreatmentRequestBody to handle AdditionalProperties
type FetchTreatmentResponse ¶
type FetchTreatmentResponse struct {
Body []byte
HTTPResponse *http.Response
JSON200 *struct {
Data *externalRef0.SelectedTreatment `json:"data,omitempty"`
}
JSON400 *externalRef0.Error
JSON500 *externalRef0.Error
}
func ParseFetchTreatmentResponse ¶
func ParseFetchTreatmentResponse(rsp *http.Response) (*FetchTreatmentResponse, error)
ParseFetchTreatmentResponse parses an HTTP response from a FetchTreatmentWithResponse call
func (FetchTreatmentResponse) Status ¶
func (r FetchTreatmentResponse) Status() string
Status returns HTTPResponse.Status
func (FetchTreatmentResponse) StatusCode ¶
func (r FetchTreatmentResponse) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type FetchTreatmentSuccess ¶
type FetchTreatmentSuccess struct {
Data *externalRef0.SelectedTreatment `json:"data,omitempty"`
}
FetchTreatmentSuccess defines model for FetchTreatmentSuccess.
type HttpRequestDoer ¶
Doer performs HTTP requests.
The standard http.Client implements this interface.
type InternalServerError ¶
type InternalServerError externalRef0.Error
InternalServerError defines model for InternalServerError.