Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageQueueConfig ¶
type MessageQueueConfig struct {
// The type of Message Queue for event updates
Kind MessageQueueKind `json:"kind" default:""`
// PubSubConfig captures the config related to publishing and subscribing to a PubSub Message Queue
PubSubConfig *PubSubConfig `json:"pub_sub_config"`
}
type MessageQueueKind ¶
type MessageQueueKind = string
MessageQueueKind describes the message queue for transmitting event updates to and fro Treatment Service
const ( // NoopMQ is a No-Op Message Queue NoopMQ MessageQueueKind = "" // PubSubMQ is a PubSub Message Queue PubSubMQ MessageQueueKind = "pubsub" )
type PubSubConfig ¶
type PubSubConfig struct {
Project string `json:"project" default:"dev" validate:"required"`
TopicName string `json:"topic_name" default:"xp-update" validate:"required"`
// PubSubTimeoutSeconds is the duration beyond which subscribing to a topic will time out
PubSubTimeoutSeconds int `json:"pub_sub_timeout_seconds" default:"30" validate:"required"`
}
Click to show internal directories.
Click to hide internal directories.